@@ -639,7 +639,7 @@ Aquest programa està basat en ObConf que ha estat desenvolupat pels següents d
     <message>
         <location filename="../archive.cpp" line="26"/>
         <source>&quot;%1&quot; was installed to %2</source>
-        <translation type="unfinished">&quot;%2&quot; ha estat instal·lat a %2 {1&quot;?}</translation>
+        <translation>&quot;%1&quot; ha estat instal·lat a %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
