@@ -639,7 +639,7 @@ The program is based on ObConf developed by the following developers.
     <message>
         <location filename="../archive.cpp" line="26"/>
         <source>&quot;%1&quot; was installed to %2</source>
-        <translation>Το «%2» εγκαταστάθηκε στο %2</translation>
+        <translation>Το «%1» εγκαταστάθηκε στο %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
@@ -740,19 +740,22 @@ Options:
         <location filename="../obconf-qt.cpp" line="97"/>
         <source>--install requires an argument
 </source>
-        <translation>Η επιλογή «--install» απαιτεί ένα όρισμα</translation>
+        <translation>Η επιλογή «--install» απαιτεί ένα όρισμα
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="103"/>
         <source>--archive requires an argument
 </source>
-        <translation>Η επιλογή «--archive» απαιτεί ένα όρισμα</translation>
+        <translation>Η επιλογή «--archive» απαιτεί ένα όρισμα
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="109"/>
         <source>--config-file requires an argument
 </source>
-        <translation>Η επιλογή «--config» απαιτεί ένα όρισμα</translation>
+        <translation>Η επιλογή «--config-file» απαιτεί ένα όρισμα
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="223"/>
