@@ -6,7 +6,7 @@
     <message>
         <location filename="../fontbutton.cpp" line="46"/>
         <source>Bold</source>
-        <translation>Жирний</translation>
+        <translation>Грубий</translation>
     </message>
     <message>
         <location filename="../fontbutton.cpp" line="50"/>
@@ -95,7 +95,7 @@
     <message>
         <location filename="../obconf.ui" line="710"/>
         <source>Focus windows when the mouse pointer moves over them</source>
-        <translation>Фокусування вікон, якщо вказівник миші знаходиться над ними</translation>
+        <translation>Фокусування вікон, якщо вказівник миші розташовано над ними</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="768"/>
@@ -110,7 +110,7 @@
     <message>
         <location filename="../obconf.ui" line="911"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
-        <translation>Поля робочого столу - це зарезервовані ділянки на краю Вашого екрану. Нові вікна не будуть поміщені за цими межами, а максимізовані вікна не будуть закривати їх.</translation>
+        <translation>Поля стільниці — це зарезервовані ділянки на краю вашого екрана. Нові вікна не будуть поміщені по за цими межами, а розгорнені вікна не затулятимуть їх.</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="921"/>
@@ -123,7 +123,7 @@
         <location filename="../obconf.ui" line="977"/>
         <location filename="../obconf.ui" line="998"/>
         <source>px</source>
-        <translation>пт</translation>
+        <translation>пікселів</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="942"/>
@@ -255,10 +255,10 @@ M: Maximize
 C: Close
 S: Shade (Roll up)
 D: Omnipresent (On all desktops)</source>
-        <translation>N: Іконка вікна
+        <translation>N: Піктограма вікна
 L: Мітка вікна (Назва)
-I: Іконка (Мінімізація)
-M: Максимізація
+I: Піктограма (Зменшити)
+M: Розгорнути
 C: Закрити
 S: Затінити (Згорнути)
 D: Розмістити всюди (На всіх стільницях)</translation>
@@ -346,7 +346,7 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="1169"/>
         <source>&amp;Orientation: </source>
-        <translation>&amp;Орієнтація:</translation>
+        <translation>&amp;Орієнтація: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1183"/>
@@ -366,7 +366,7 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="1205"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation>Помістити док &amp;над іншими вікнами </translation>
+        <translation>Помістити док &amp;над іншими вікнами</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1212"/>
@@ -396,7 +396,7 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="1275"/>
         <source>&amp;Hide off screen</source>
-        <translation>П&amp;риховування поза екраном </translation>
+        <translation>С&amp;ховати з екрана</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="1306"/>
@@ -421,27 +421,27 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="127"/>
         <source>A&amp;nimate iconify and restore</source>
-        <translation>Ані&amp;мація значків і відновлення</translation>
+        <translation>Ані&amp;мація піктограм і відновлення</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="231"/>
         <source>&amp;Active window title: </source>
-        <translation>Назва &amp;активного вікна:</translation>
+        <translation>Назва &amp;активного вікна: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="241"/>
         <source>&amp;Inactive window title: </source>
-        <translation>Назва &amp;неактивного вікна:</translation>
+        <translation>Назва &amp;неактивного вікна: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="251"/>
         <source>Menu &amp;header: </source>
-        <translation>Заголово&amp;к меню:</translation>
+        <translation>Заголово&amp;к меню: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="261"/>
         <source>&amp;Menu Item: </source>
-        <translation>П&amp;ункт меню:</translation>
+        <translation>П&amp;ункт меню: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="271"/>
@@ -451,12 +451,12 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="281"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation>Неактивне від&amp;ображення на екрані:</translation>
+        <translation>Неактивне від&amp;ображення на екрані: </translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="295"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation>Фокусувати &amp;нове вікно коли воно появляється</translation>
+        <translation>Фокусуватися на &amp;новому вікні коли воно з&apos;являється</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="302"/>
@@ -491,27 +491,27 @@ D: Розмістити всюди (На всіх стільницях)</transla
     <message>
         <location filename="../obconf.ui" line="452"/>
         <source>Drag &amp;threshold distance:</source>
-        <translation type="unfinished"></translation>
+        <translation>Відс&amp;туп під час перетягування:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="472"/>
         <source>Amount of resistance against other &amp;windows:</source>
-        <translation type="unfinished"></translation>
+        <translation>Сила опору до інших &amp;вікон:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="492"/>
         <source>Amount of resistance against screen &amp;edges:</source>
-        <translation type="unfinished"></translation>
+        <translation>Сила опору до меж &amp;екрана:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="512"/>
         <source>&amp;Amount of time to wait before switching:</source>
-        <translation>&amp;Час очікування перед переключанням:</translation>
+        <translation>&amp;Час очікування до перемикання:</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="532"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
-        <translation type="unfinished"></translation>
+        <translation>Перемикати робочий стіл під час переміщення вікна за край екрана</translation>
     </message>
     <message>
         <location filename="../obconf.ui" line="567"/>
@@ -639,7 +639,7 @@ The program is based on ObConf developed by the following developers.
     <message>
         <location filename="../archive.cpp" line="26"/>
         <source>&quot;%1&quot; was installed to %2</source>
-        <translation type="unfinished">&quot;%2&quot; встановлено до %2 {1&quot;?}</translation>
+        <translation>«%1» встановлено до %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
@@ -682,10 +682,10 @@ The following errors were reported:
 Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
 The following errors were reported:
 %3</source>
-        <translation>Неможливо розпакувати файл &quot;%1&quot;.
-Будь ласка, впевніться, що у &quot;%2&quot; можна записувати і що файл є справжнім архівом теми Openbox.
-Сталися наступні помилки :
-%3 </translation>
+        <translation>Неможливо розпакувати файл «%1».
+Впевніться, що до «%2» можна записувати і що файл є справжнім архівом теми Openbox.
+Сталися такі помилки :
+%3</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="53"/>
@@ -743,7 +743,7 @@ Options:
     <message>
         <location filename="../obconf-qt.cpp" line="224"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
-        <translation>Помилка завантаження rc.xml. Можливо Ви не встановили правильно Openbox.</translation>
+        <translation>Помилка завантаження rc.xml. Можливо ви встановили Openbox не правильно.</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="236"/>
@@ -771,8 +771,8 @@ under certain conditions. See the file COPYING for details.
 Всі права застережено (c) 2007        Javeed Shaikh
 Всі права застережено (c) 2013        Hong Jen Yee (PCMan)
 
-Ця програма поставляється без всяких гарантій.
-Це вільне програмне забезпечення, і Ви можете поширювати
+Ця програма поставляється без жодних гарантій.
+Це вільне програмне забезпечення і ви можете поширювати
 його за певних умов. Див. файл з назвою COPYING для деталей.
 
 </translation>
